import json
import os


def load_data():
    # Load data from first existing of these
    candidate_paths = [
        os.path.join(os.path.dirname(os.path.dirname(__file__)), "data.json"),
        "/usr/share/cdn-definitions/data.json",
    ]

    # If env var is set, it takes highest precedence
    if "CDN_DEFINITIONS_PATH" in os.environ:
        candidate_paths.insert(0, os.environ["CDN_DEFINITIONS_PATH"])

    existing_paths = [p for p in candidate_paths if os.path.exists(p)]
    return json.load(open(existing_paths[0]))


DATA = load_data()


class PathAlias(object):
    """Represents an alias between one CDN path and another, generally
    used to make two directory trees on CDN serve identical content."""

    def __init__(self, **kwargs):
        self.src = kwargs["src"]
        """Source path of mapping (e.g. "/content/rhel/dist/rhui")."""

        self.dest = kwargs["dest"]
        """Destination path of mapping (e.g. "/content/rhel/dist")."""

        # Enforce a few invariants:
        # absolute paths only
        if not self.src.startswith("/") or not self.dest.startswith("/"):
            raise ValueError("Attempted to construct PathAlias with relative path")

        # Equal src/dest is nonsensical
        if self.src == self.dest:
            raise ValueError("%s cannot alias itself!" % self.src)


def rhui_aliases():
    """Returns:
        list[:class:`~PathAlias`]
            A list of aliases relating to RHUI paths.
    """
    return [PathAlias(**elem) for elem in DATA["rhui_alias"]]


def origin_aliases():
    """Returns:
        list[:class:`~PathAlias`]
            A list of aliases relating to origin paths.
    """
    return [PathAlias(**elem) for elem in DATA["origin_alias"]]



from setuptools import setup, find_packages


def get_description():
    return "Data definitions for Red Hat's content delivery network"


def get_long_description():
    with open("README.md") as f:
        text = f.read()

    # Long description is everything after README's initial heading
    idx = text.find("\n\n")
    return text[idx:]


setup(
    name="cdn-definitions",
    version="1.3.0",
    author="Rohan McGovern",
    author_email="rmcgover@redhat.com",
    packages=find_packages("src"),
    package_dir={"": "src"},
    url="https://github.com/release-engineering/cdn-definitions",
    license="GNU General Public License",
    description=get_description(),
    include_package_data=True,
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    project_urls={
        "Documentation": "https://release-engineering.github.io/cdn-definitions/",
        "Changelog": "https://github.com/release-engineering/cdn-definitions/blob/master/CHANGELOG.md",
    },
)
